@@ -1,8 +1,6 @@
 
-__all__ = ["MplWidget"]
-
 from PySide6 import QtCore, QtUiTools
-from mplwidget import MplWidget
+from pyCftool.mplwidget import MplWidget
 
 def loadUiWidget(uifilename, parent=None):
     loader = QtUiTools.QUiLoader()
